/**********************************************************************************

    ____  ____     ___  __ __  ___    __ __  ____  ____    ___  
   |    \|    \   /  _]|  |  ||   \  |  |  ||    ||    \  /   \ 
   |  o  )  _  | /  [_ |  |  ||    \ |  |  | |  | |  _  ||     |
   |   _/|  |  ||    _]|  |  ||  D  ||  |  | |  | |  |  ||  O  |
   |  |  |  |  ||   [_ |  :  ||     ||  :  | |  | |  |  ||     |
   |  |  |  |  ||     ||     ||     ||     | |  | |  |  ||     |
   |__|  |__|__||_____| \__,_||_____| \__,_||____||__|__| \___/ 

   PneuDuino is a toolkit for controlling inflatable actuators
   and prototyping interactions with shape-changing systems.

   Every slave board has a RGB led on the top right corner that communicates
   the state of this board.

   GREEN - baord running and connecting
   RED - board running, but not connected
   BLUE - board not running yet (usually after reset or power) or broken :(

   The boards addresses range from 1-12. 12 is reserved for IO Boards.
   There can ONLY BE ONE IO BOARD per system.

   The library offers functions that allow for controlling the valves and 
   accessing the pressure sensor :

   begin() - should be called at the beginning of setup()
   update() - should be called at the beginning of loop()

   void in(address, side) - inflates bag of board with defined address
   void out(address, side) - deflates bag of board with defined address
   int readPressure(address) - returns pressure of bag at defined address. 
                              Notice that a non-deflated bag still experiences 
                              athmospheric pressure and thus does not return 0.
   bool readButton(side) - returns button state of IO Board. 0 is top, 1 is bottom.
   int readPot() - returns potentiometer value of IO Board. 0 - 15.

   |||

   Heart Rate Sensor Example Code Information

   The Grove Heart Rate sensor is a simple IC based on a high performance and low
   power CMOS-process optical sensor with Green LED and DSP integrated serving as a 
   Heart Rate Detection (HRD) sensor. The module is based on optical technology 
   which measures the variation in human blood movement in the vessel. 

   This example code allows you to read the heart rate at half second interval, and
   implement this data into an inflatable application.

   |||

   Functions and Values

   Variable 'heartrate' should be on scale of real heart rate. 
   
**********************************************************************************/

#include <Wire.h>
#include <PneuDuinoExp.h>
unsigned long previousMillis = 0;
const long interval = 500;    //  Interval for updating heart rate sensor data
int heartrate = 0;    //  Initializing variable for storing heart rate
PneuDuinoExp air = PneuDuinoExp();    //  Creating instance of PneuDuino class

void setup() {
    Serial.begin(9600); //  Initializing Serial communications
    while(!Serial); //  ** WAITS UNTIL SERIAL WINDOW IS OPENED TO START EXECUTING **
    Serial.println("- Heart Rate Sensor Initialized -");
    air.begin();  //  Initializes Pneuduino Setup 
}
void loop() {
air.update();   // Updates the master Pneuduino board on the state of slave boards
unsigned long currentMillis = millis();   // Updates variable currentMillis with the time in milliseconds
if (currentMillis - previousMillis >= interval){
  previousMillis = currentMillis;
  Wire.requestFrom(0xA0 >> 1, 1);    // Requests data from the Grove Heart Rate Sensor
  while(Wire.available()) {          
    unsigned int c = Wire.read();   // Receives data from Grove Heart Rate Sensor
    heartrate = c;
  }
  Serial.println(heartrate);  // Prints out Grove Heart Rate Data
}

air.out(6,LEFT);
if (currentMillis - previousMillis >= heartrate){
  air.in(6,LEFT);
  delay(heartrate);
}
air.out(6,LEFT);
}
